Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7473)

Unified Diff: chrome/installer/setup/setup_main.cc

Issue 2841783002: Don't uninstall Google Update for Windows Installer-driven uninstalls. (Closed)
Patch Set: fix typo Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/setup/setup_main.cc
diff --git a/chrome/installer/setup/setup_main.cc b/chrome/installer/setup/setup_main.cc
index d76f6ce6c2dcd7f530ca88f1736375576eaaa727..2627ecc32c7e775ea08ea6f2d7ae1d2f29b018f0 100644
--- a/chrome/installer/setup/setup_main.cc
+++ b/chrome/installer/setup/setup_main.cc
@@ -628,10 +628,13 @@ installer::InstallStatus UninstallProducts(
if (!system_level_cmd.GetProgram().empty())
base::LaunchProcess(system_level_cmd, base::LaunchOptions());
- // Tell Google Update that an uninstall has taken place.
- // Ignore the return value: success or failure of Google Update
- // has no bearing on the success or failure of Chrome's uninstallation.
- google_update::UninstallGoogleUpdate(installer_state.system_install());
+ // Tell Google Update that an uninstall has taken place if this install did
+ // not originate from the MSI. Google Update has its own logic relating to
+ // MSI-driven uninstalls that conflicts with this. Ignore the return value:
+ // success or failure of Google Update has no bearing on the success or
+ // failure of Chrome's uninstallation.
+ if (!installer_state.is_msi())
+ google_update::UninstallGoogleUpdate(installer_state.system_install());
return install_status;
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698